@@ -1,5 +1,20 @@
 # -*- coding: utf-8 -*-
 
+# Copyright (C) 2013  Chenxiong Qi
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 from contextlib import contextmanager
 from datetime import datetime
 from utils import get_tgt_time
@@ -7,34 +22,34 @@ from utils import get_login
 from threading import Lock
 
 import krbV
-import os, sys
+import os
+import sys
 import subprocess
 
 
-__all__ = ( 'krbcontext',
-            'KRB5InitError', )
+__all__ = ('krbcontext', 'KRB5InitError')
 
 
 ENV_KRB5CCNAME = 'KRB5CCNAME'
 __init_lock = Lock()
 
+
 # TODO: put this into standalone module
 class KRB5InitError(Exception):
     pass
 
+
 def init_ccache_as_regular_user(principal, ccache):
     '''Initialize credential cache as a regular user
 
     Return the filename of newly initialized credential cache
     '''
-    cmd = 'kinit -c %(ccache_file)s %(principal)s'
-    args = { 'principal': principal.name,
-             'ccache_file': ccache.name, }
+    args = {'principal': principal.name, 'ccache_file': ccache.name}
+    cmd = 'kinit -c %(ccache_file)s %(principal)s' % args
+    cmd_to_execute = cmd.split()
 
     __init_lock.acquire()
-    kinit_proc = subprocess.Popen(
-        (cmd % args).split(),
-        stderr=subprocess.PIPE)
+    kinit_proc = subprocess.Popen(cmd_to_execute, stderr=subprocess.PIPE)
     stdout_data, stderr_data = kinit_proc.communicate()
     __init_lock.release()
 
@@ -43,6 +58,7 @@ def init_ccache_as_regular_user(principal, ccache):
 
     return ccache.name
 
+
 def init_ccache_with_keytab(principal, keytab, ccache):
     ''' Initialize credential cache using keytab file.
 
@@ -54,12 +70,14 @@ def init_ccache_with_keytab(principal, keytab, ccache):
     __init_lock.release()
     return ccache.name
 
+
 def get_default_ccache(context):
     if ENV_KRB5CCNAME in os.environ:
         return krbV.CCache(os.environ[ENV_KRB5CCNAME], context=context)
     else:
         return context.default_ccache()
 
+
 def is_initialize_ccache_necessary(context, ccache, principal):
     ''' Judge whether initializing credential cache is necessary.
 
@@ -98,15 +116,16 @@ def is_initialize_ccache_necessary(context, ccache, principal):
         raise
     return datetime.now() >= cred_time.endtime
 
+
 def clean_kwargs(context, kwargs):
     ''' Clean argument to related object
 
     In the case of using Key table, principal is required. keytab_file is
-    optional, and default key table file /etc/krb5.keytab is used if keytab_file
-    is not provided.
+    optional, and default key table file /etc/krb5.keytab is used if
+    keytab_file is not provided.
 
-    In the case of initing as a regular user, principal is optional, and current
-    user's effective name is used if principal is not provided.
+    In the case of initing as a regular user, principal is optional, and
+    current user's effective name is used if principal is not provided.
 
     By default, initialize credentials cache for regular user.
     '''
@@ -148,19 +167,24 @@ def clean_kwargs(context, kwargs):
 
     return cleaned_kwargs
 
+
 def init_ccache_if_necessary(context, kwargs):
     ''' Initialize credential cache if necessary.
 
+    The original credential cache is saved and returned for recovery in the
+    final step. And the specified one is assigned to KRB5CCNAME in current
+    process.
+
     Arguments:
     - context: current krb5 context.
     - kwargs: cleaned kwargs passed to krbcontext.
     '''
     ccache = kwargs['ccache']
     principal = kwargs['principal']
-    old_ccache = None
+    old_ccache = os.getenv(ENV_KRB5CCNAME)
     init_required = is_initialize_ccache_necessary(context, ccache, principal)
+    ccache_file = ccache.name
     if init_required:
-        old_ccache = os.getenv(ENV_KRB5CCNAME)
         if kwargs['using_keytab']:
             keytab = kwargs['keytab']
             ccache_file = init_ccache_with_keytab(principal, keytab, ccache)
@@ -168,13 +192,15 @@ def init_ccache_if_necessary(context, kwargs):
             # If client script is not running in terminal, it is impossible for
             # user to enter his/her password.
             if not sys.stdin.isatty():
-                raise IOError('This is not running on console. So, you need to '
-                              'run kinit with your principal manually before '
-                              'anything goes.')
+                msg = 'This is not running on console. So, you need to ' \
+                      'run kinit with your principal manually before ' \
+                      'anything goes.'
+                raise IOError(msg)
             ccache_file = init_ccache_as_regular_user(principal, ccache)
-        os.environ[ENV_KRB5CCNAME] = ccache_file
+    os.environ[ENV_KRB5CCNAME] = ccache_file
     return (init_required, old_ccache)
 
+
 @contextmanager
 def krbcontext(**kwargs):
     '''A context manager for Kerberos-related actions
@@ -197,4 +223,3 @@ def krbcontext(**kwargs):
                 os.environ[ENV_KRB5CCNAME] = old_ccache
             else:
                 del os.environ[ENV_KRB5CCNAME]
-
