@@ -2,8 +2,7 @@
 
 import context as kctx
 
-from context import get_login
-from context import init_ccache_as_regular_user
+from context import ENV_KRB5CCNAME
 from context import init_ccache_with_keytab
 from context import is_initialize_ccache_necessary
 from context import KRB5InitError
@@ -12,7 +11,6 @@ from utils import get_tgt_time
 
 import krbV
 import os
-import subprocess
 import tests_config as config
 import time
 import textwrap
@@ -26,22 +24,28 @@ def init_user_ccache(lifetime=None):
         'ccache': config.user_ccache_file, }
     os.system(cmd)
 
+
 def init_ccache_using_keytab(lifetime=None):
-    cmd = 'kinit %(lifetime)s -c %(ccache)s -k -t %(keytab)s %(princ)s' % {
+    args = {
         'lifetime': '-l %s' % lifetime if lifetime is not None else '',
         'keytab': config.user_keytab_file,
         'princ': config.service_principal,
-        'ccache': config.user_ccache_file, }
+        'ccache': config.user_ccache_file,
+    }
+    cmd = 'kinit %(lifetime)s -c %(ccache)s -k -t %(keytab)s %(princ)s' % args
     os.system(cmd)
 
+
 def krb_default_cc_name():
     context = krbV.default_context()
     return context.default_ccache().name
 
+
 def krb_default_keytab_name():
     context = krbV.default_context()
     return context.default_keytab().name
 
+
 def get_tgt_time_from_ccache(principal_name):
     context = krbV.default_context()
     principal = krbV.Principal(principal_name, context=context)
@@ -49,12 +53,31 @@ def get_tgt_time_from_ccache(principal_name):
     ct = get_tgt_time(context, ccache, principal)
     return ct.endtime
 
-class CCacheInitializationRequiredTest(unittest.TestCase):
+
+class OriginalKRB5CCNAMESafeMixin(object):
+    '''Ensure the original system's KRB5CCNAME is safe'''
+
+    def protect_KRB5CCNAME(self):
+        self._original_krb5ccname_env = os.getenv(ENV_KRB5CCNAME)
+
+    def recovery_KRB5CCNAME(self):
+        has_krb5ccname_in_process = self._original_krb5ccname_env is not None
+        if has_krb5ccname_in_process:
+            os.environ[ENV_KRB5CCNAME] = self._original_krb5ccname_env
+        else:
+            krb5ccname_set_in_testcases = ENV_KRB5CCNAME in os.environ
+            if krb5ccname_set_in_testcases:
+                del os.environ[ENV_KRB5CCNAME]
+
+
+class CCacheInitializationRequiredTest(unittest.TestCase,
+                                       OriginalKRB5CCNAMESafeMixin):
     def setUp(self):
-        os.environ['KRB5CCNAME'] = config.user_ccache_file
+        self.protect_KRB5CCNAME()
+        os.environ[ENV_KRB5CCNAME] = config.user_ccache_file
 
     def tearDown(self):
-        del os.environ['KRB5CCNAME']
+        self.recovery_KRB5CCNAME()
 
     def testCCacheFileNotFound(self):
         os.system('kdestroy -c %s 2>/dev/null' % config.user_ccache_file)
@@ -123,20 +146,26 @@ class CCacheInitializationRequiredTest(unittest.TestCase):
         result = is_initialize_ccache_necessary(context, ccache, principal)
         self.assertFalse(result)
 
-class GetDefaultCCacheTest(unittest.TestCase):
+
+class GetDefaultCCacheTest(unittest.TestCase, OriginalKRB5CCNAMESafeMixin):
     def setUp(self):
         self.context = krbV.default_context()
+        self.protect_KRB5CCNAME()
+
+    def tearDown(self):
+        self.recovery_KRB5CCNAME()
 
     def testFromEnvironmentVariable(self):
-        os.environ['KRB5CCNAME'] = config.user_ccache_file
+        os.environ[ENV_KRB5CCNAME] = config.user_ccache_file
         ccache = kctx.get_default_ccache(self.context)
-        del os.environ['KRB5CCNAME']
         self.assertEqual(ccache.name, config.user_ccache_file)
 
     def testFromKerberosDefaultCCacheName(self):
         ccache = kctx.get_default_ccache(self.context)
-        default_cc_name = '/tmp/krb5cc_%d' % os.getuid()
-        self.assertTrue(ccache.name.endswith(default_cc_name))
+        ccache_file = ccache.name.lstrip(':')
+        default_cc_name = '/run/user/%d/krb5cc' % os.getuid()
+        self.assertTrue(ccache_file.startswith(default_cc_name))
+
 
 class CleanArgumetsUsingKeytabTest(unittest.TestCase):
     def setUp(self):
@@ -192,9 +221,11 @@ class CleanArgumetsUsingKeytabTest(unittest.TestCase):
         self.assert_('keytab' in cleaned_kwargs)
         kt = cleaned_kwargs['keytab']
         expected_kt_name = config.user_keytab_file
-        self.assert_(kt.name.endswith(expected_kt_name),
-                         'Key table %s should contain expected filename %s.' % (
-                            kt.name, expected_kt_name))
+        self.assert_(
+            kt.name.endswith(expected_kt_name),
+            'Key table %s should contain expected filename %s.' % (
+                kt.name, expected_kt_name))
+
 
 class CleanArgumetsAsRegularUserTest(unittest.TestCase):
     def setUp(self):
@@ -234,6 +265,7 @@ class CleanArgumetsAsRegularUserTest(unittest.TestCase):
         ccache = cleaned_kwargs['ccache']
         self.assertEqual(ccache.name, config.user_ccache_file)
 
+
 class InitAsRegularUserTest(unittest.TestCase):
     def _setUp(self):
         self.context = krbV.default_context()
@@ -259,6 +291,7 @@ class InitAsRegularUserTest(unittest.TestCase):
         testInitializationWithWrongArguments = \
             _testInitializationWithWrongArguments
 
+
 class InitUsingKeytabTest(unittest.TestCase):
     def setUp(self):
         self.context = krbV.default_context()
@@ -275,11 +308,13 @@ class InitUsingKeytabTest(unittest.TestCase):
                                           self.ccache)
         self.assert_(cc_name.endswith(self.ccache.name))
 
+
 class krbcontextUsingKeytabTest(unittest.TestCase):
 
     def setUp(self):
         init_ccache_using_keytab(lifetime='3s')
 
+        self.sleep_seconds_for_expiration = 5
         self.kwargs = {
             'using_keytab': True,
             'principal': config.service_principal,
@@ -292,7 +327,6 @@ class krbcontextUsingKeytabTest(unittest.TestCase):
         os.system(cmd)
 
     def testInitializeCCacheIsNotRequired(self):
-        import os
         expected_endtime = get_tgt_time_from_ccache(config.service_principal)
         with krbcontext(**self.kwargs):
             pass
@@ -302,7 +336,7 @@ class krbcontextUsingKeytabTest(unittest.TestCase):
     def testInitializeCCacheWhenTGTExpires(self):
         endtime_before_init = get_tgt_time_from_ccache(config.service_principal)
         # Sleep for a while to make TGT expired
-        time.sleep(5)
+        time.sleep(self.sleep_seconds_for_expiration)
         with krbcontext(**self.kwargs):
             pass
         test_endtime = get_tgt_time_from_ccache(config.service_principal)
@@ -321,4 +355,3 @@ if __name__ == '__main__':
     print '\n'.join(textwrap.wrap(help_msg, 80))
 
     unittest.main()
-
